@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+from typing import cast
 from urllib.parse import urljoin
 
 from social_core.utils import cache
@@ -10,12 +13,11 @@ class Fence(OpenIdConnectAuth):
     name = "fence"
     OIDC_ENDPOINT = "https://nci-crdc.datacommons.io"
     ID_KEY = "username"
-    ACCESS_TOKEN_METHOD = "POST"
     DEFAULT_SCOPE = ["openid", "user"]
     JWT_DECODE_OPTIONS = {"verify_at_hash": False}
 
     def _url(self, path):
-        return urljoin(append_slash(self.OIDC_ENDPOINT), path)
+        return urljoin(append_slash(cast("str", self.OIDC_ENDPOINT)), path)
 
     def authorization_url(self):
         return self._url("user/oauth2/authorize")
