@@ -2,7 +2,7 @@
 Google App Engine support using User API
 """
 
-from google.appengine.api import users  # type: ignore[reportMissingImports]
+from google.appengine.api import users
 
 from ..exceptions import AuthException
 from .base import BaseAuth
@@ -38,6 +38,6 @@ class GoogleAppEngineAuth(BaseAuth):
     def auth_complete(self, *args, **kwargs):
         """Completes login process, must return user instance."""
         if not users.get_current_user():
-            raise AuthException("Authentication error")
+            raise AuthException(self, "Authentication error")
         kwargs.update({"response": "", "backend": self})
         return self.strategy.authenticate(*args, **kwargs)
