@@ -10,10 +10,8 @@ Terminology:
 
 import json
 
-from onelogin.saml2.auth import OneLogin_Saml2_Auth  # type: ignore reportMissingImports
-from onelogin.saml2.settings import (  # type: ignore reportMissingImports
-    OneLogin_Saml2_Settings,
-)
+from onelogin.saml2.auth import OneLogin_Saml2_Auth
+from onelogin.saml2.settings import OneLogin_Saml2_Settings
 
 from ..exceptions import AuthFailed, AuthMissingParameter
 from .base import BaseAuth
