@@ -5,6 +5,10 @@ Docs at:
     https://python-social-auth.readthedocs.io/en/latest/backends/udata.html
 """
 
+from __future__ import annotations
+
+from social_core.exceptions import AuthMissingParameter
+
 from .oauth import BaseOAuth2
 
 
@@ -14,8 +18,7 @@ class UdataBaseOAuth2(BaseOAuth2):
     SCOPE_SEPARATOR = ","
     REDIRECT_STATE = False
     DEFAULT_SCOPE = ["default"]
-    ACCESS_TOKEN_METHOD = "POST"
-    USER_DATA_URL = None
+    USER_DATA_URL: str | None = None
 
     def get_user_details(self, response):
         """Return user details from Udata account."""
@@ -27,6 +30,8 @@ class UdataBaseOAuth2(BaseOAuth2):
 
     def user_data(self, access_token, *args, **kwargs):
         """Load user data from service."""
+        if self.USER_DATA_URL is None:
+            raise AuthMissingParameter(self, "USER_DATA_URL")
         return self.get_json(self.USER_DATA_URL, params={"access_token": access_token})
 
 
