@@ -3,9 +3,12 @@ VK.com OpenAPI, OAuth2 and Iframe application OAuth2 backends, docs at:
     https://python-social-auth.readthedocs.io/en/latest/backends/vk.html
 """
 
+from __future__ import annotations
+
 import json
 from hashlib import md5
 from time import time
+from typing import Any, cast
 
 from ..exceptions import AuthException, AuthTokenRevoked
 from ..utils import parse_qs
@@ -13,6 +16,15 @@ from .base import BaseAuth
 from .oauth import BaseOAuth2
 
 
+def vk_sig(payload: str) -> str:
+    """
+    Calculates signature using md5.
+
+    https://dev.vk.com/en/api/open-api/getting-started#Authorization%20on%20the%20Remote%20Side
+    """
+    return md5(payload.encode("utf-8")).hexdigest()  # noqa: S324
+
+
 class VKontakteOpenAPI(BaseAuth):
     """VK.COM OpenAPI authentication backend"""
 
@@ -61,7 +73,7 @@ class VKontakteOpenAPI(BaseAuth):
         )
 
         key, secret = self.get_key_and_secret()
-        hash = md5((check_str + secret).encode("utf-8")).hexdigest()
+        hash = vk_sig(check_str + secret)
         if hash != mapping["sig"] or int(mapping["expire"]) < time():
             raise ValueError("VK.com authentication failed: Invalid Hash")
 
@@ -82,7 +94,6 @@ class VKOAuth2(BaseOAuth2):
     ID_KEY = "id"
     AUTHORIZATION_URL = "https://oauth.vk.com/authorize"
     ACCESS_TOKEN_URL = "https://oauth.vk.com/access_token"
-    ACCESS_TOKEN_METHOD = "POST"
     EXTRA_DATA = [("id", "id"), ("expires_in", "expires")]
 
     def get_user_details(self, response):
@@ -110,8 +121,7 @@ class VKOAuth2(BaseOAuth2):
         ]
 
         fields = ",".join(set(request_data))
-        data = vk_api(
-            self,
+        response = self.vk_api(
             "users.get",
             {
                 "access_token": access_token,
@@ -119,17 +129,44 @@ class VKOAuth2(BaseOAuth2):
             },
         )
 
-        if data and data.get("error"):
-            error = data["error"]
+        if response and response.get("error"):
+            error = response["error"]
             msg = error.get("error_msg", "Unknown error")
             if error.get("error_code") == 5:
                 raise AuthTokenRevoked(self, msg)
             raise AuthException(self, msg)
 
-        if data:
-            data = data.get("response")[0]
+        if response:
+            data = cast("list[dict[str, str | None]]", response.get("response"))[0]
             data["user_photo"] = data.get("photo")  # Backward compatibility
-        return data or {}
+            return data
+        return {}
+
+    def vk_api(self, method: str, data: dict[str, str]) -> dict[Any, Any] | None:
+        """
+        Calls VK.com OpenAPI method, check:
+            https://vk.com/apiclub
+            http://goo.gl/yLcaa
+        """
+        # We need to perform server-side call if no access_token
+        data["v"] = self.setting("API_VERSION", "5.131")
+        if "access_token" not in data:
+            key, secret = self.get_key_and_secret()
+            if "api_id" not in data:
+                data["api_id"] = key
+
+            data["method"] = method
+            data["format"] = "json"
+            url = "https://api.vk.com/api.php"
+            param_list = sorted(item + "=" + data[item] for item in data)
+            data["sig"] = vk_sig("".join(param_list) + secret)
+        else:
+            url = "https://api.vk.com/method/" + method
+
+        try:
+            return self.get_json(url, params=data)
+        except (TypeError, KeyError, OSError, ValueError, IndexError):
+            return None
 
 
 class VKAppOAuth2(VKOAuth2):
@@ -147,9 +184,7 @@ class VKAppOAuth2(VKOAuth2):
         # Verify signature, if present
         key, secret = self.get_key_and_secret()
         if auth_key:
-            check_key = md5(
-                "_".join([key, self.data.get("viewer_id"), secret]).encode("utf-8")
-            ).hexdigest()
+            check_key = vk_sig("_".join([key, self.data.get("viewer_id"), secret]))
             if check_key != auth_key:
                 raise ValueError("VK.com authentication failed: invalid auth key")
 
@@ -160,7 +195,7 @@ class VKAppOAuth2(VKOAuth2):
             if user_check == 1:
                 is_user = self.data.get("is_app_user")
             elif user_check == 2:
-                is_user = vk_api(self, "isAppUser", {"user_id": user_id}).get(
+                is_user = self.vk_api("isAppUser", {"user_id": user_id}).get(
                     "response", 0
                 )
             if not int(is_user):
@@ -178,30 +213,3 @@ class VKAppOAuth2(VKOAuth2):
             json.loads(auth_data["request"]["api_result"])["response"][0]
         )
         return self.strategy.authenticate(*args, **auth_data)
-
-
-def vk_api(backend, method, data):
-    """
-    Calls VK.com OpenAPI method, check:
-        https://vk.com/apiclub
-        http://goo.gl/yLcaa
-    """
-    # We need to perform server-side call if no access_token
-    data["v"] = backend.setting("API_VERSION", "5.131")
-    if "access_token" not in data:
-        key, secret = backend.get_key_and_secret()
-        if "api_id" not in data:
-            data["api_id"] = key
-
-        data["method"] = method
-        data["format"] = "json"
-        url = "https://api.vk.com/api.php"
-        param_list = sorted(item + "=" + data[item] for item in data)
-        data["sig"] = md5(("".join(param_list) + secret).encode("utf-8")).hexdigest()
-    else:
-        url = "https://api.vk.com/method/" + method
-
-    try:
-        return backend.get_json(url, params=data)
-    except (TypeError, KeyError, OSError, ValueError, IndexError):
-        return None
