@@ -1,26 +1,27 @@
-# pyright: reportAttributeAccessIssue=false
+from __future__ import annotations
 
+from typing import Generic, TypeVar, cast
 from unittest.mock import patch
 from urllib.parse import urlparse
 
 import requests
-from httpretty import HTTPretty, latest_requests
+import responses
 
-from ...utils import parse_qs, url_add_parameters
+from ...backends.oauth import BaseOAuth1, BaseOAuth2, OAuthAuth
+from ...utils import get_querystring, parse_qs, url_add_parameters
 from ..models import User
 from .base import BaseBackendTest
 
+OAuthBackendT = TypeVar("OAuthBackendT", bound=OAuthAuth)
 
-class BaseOAuthTest(BaseBackendTest):
-    backend = None
-    backend_path = None
-    user_data_body = None
-    user_data_url = ""
-    user_data_url_post = False
-    user_data_content_type = "application/json"
-    access_token_body = None
-    access_token_status = 200
-    expected_username = ""
+
+class BaseOAuthTest(BaseBackendTest[OAuthBackendT], Generic[OAuthBackendT]):
+    user_data_body: str | None = None
+    user_data_url: str = ""
+    user_data_url_post: bool = False
+    user_data_content_type: str = "application/json"
+    access_token_body: str | None = None
+    access_token_status: int = 200
 
     def extra_settings(self):
         assert self.name, "Subclasses must set the name attribute"
@@ -30,9 +31,9 @@ class BaseOAuthTest(BaseBackendTest):
         }
 
     def _method(self, method):
-        return {"GET": HTTPretty.GET, "POST": HTTPretty.POST}[method]
+        return {"GET": responses.GET, "POST": responses.POST}[method]
 
-    def handle_state(self, start_url, target_url):
+    def handle_state(self, start_url: str, target_url: str) -> str:
         start_query = parse_qs(urlparse(start_url).query)
         redirect_uri = start_query.get("redirect_uri")
 
@@ -47,17 +48,20 @@ class BaseOAuthTest(BaseBackendTest):
                 )
         return target_url
 
-    def auth_handlers(self, start_url):
+    def auth_handlers(self, start_url: str) -> str:
         target_url = self.handle_state(
             start_url, self.strategy.build_absolute_uri(self.complete_url)
         )
-        HTTPretty.register_uri(
-            HTTPretty.GET, start_url, status=301, location=target_url
+        responses.add(
+            responses.GET,
+            start_url,
+            status=301,
+            headers={"Location": target_url},
         )
-        HTTPretty.register_uri(HTTPretty.GET, target_url, status=200, body="foobar")
+        responses.add(responses.GET, target_url, status=200, body="foobar")
         if self.user_data_url:
-            HTTPretty.register_uri(
-                HTTPretty.POST if self.user_data_url_post else HTTPretty.GET,
+            responses.add(
+                responses.POST if self.user_data_url_post else responses.GET,
                 self.user_data_url,
                 body=self.user_data_body or "",
                 content_type=self.user_data_content_type,
@@ -65,18 +69,18 @@ class BaseOAuthTest(BaseBackendTest):
         return target_url
 
     def pre_complete_callback(self, start_url):
-        HTTPretty.register_uri(
+        responses.add(
             self._method(self.backend.ACCESS_TOKEN_METHOD),
-            uri=self.backend.access_token_url(),
+            url=self.backend.access_token_url(),
             status=self.access_token_status,
             body=self.access_token_body or "",
-            content_type="text/json",
+            content_type="application/json",
         )
 
     def do_start(self):
         start_url = self.backend.start().url
         target_url = self.auth_handlers(start_url)
-        response = requests.get(start_url)
+        response = requests.get(start_url, timeout=1)
         self.assertEqual(response.url, target_url)
         self.assertEqual(response.text, "foobar")
         self.strategy.set_request_data(
@@ -89,13 +93,16 @@ class BaseOAuthTest(BaseBackendTest):
         return self.backend.complete()
 
 
-class OAuth1Test(BaseOAuthTest):
-    request_token_body = None
+BaseOAuth1BackendT = TypeVar("BaseOAuth1BackendT", bound=BaseOAuth1)
+
+
+class OAuth1Test(BaseOAuthTest[BaseOAuth1BackendT], Generic[BaseOAuth1BackendT]):
+    request_token_body: str
     raw_complete_url = "/complete/{0}/?oauth_verifier=bazqux&oauth_token=foobar"
 
     def request_token_handler(self):
         assert self.request_token_body, "Subclasses must set request_token_body"
-        HTTPretty.register_uri(
+        responses.add(
             self._method(self.backend.REQUEST_TOKEN_METHOD),
             self.backend.REQUEST_TOKEN_URL,
             body=self.request_token_body,
@@ -107,7 +114,10 @@ class OAuth1Test(BaseOAuthTest):
         return super().do_start()
 
 
-class OAuth2Test(BaseOAuthTest):
+BaseOAuth2BackendT = TypeVar("BaseOAuth2BackendT", bound=BaseOAuth2)
+
+
+class OAuth2Test(BaseOAuthTest[BaseOAuth2BackendT], Generic[BaseOAuth2BackendT]):
     raw_complete_url = "/complete/{0}/?code=foobar"
     refresh_token_body = ""
 
@@ -116,7 +126,7 @@ class OAuth2Test(BaseOAuthTest):
 
     def do_refresh_token(self):
         self.do_login()
-        HTTPretty.register_uri(
+        responses.add(
             self._method(self.backend.REFRESH_TOKEN_METHOD),
             self.backend.refresh_token_url(),
             status=200,
@@ -139,19 +149,26 @@ class OAuth2PkcePlainTest(OAuth2Test):
     def do_login(self):
         user = super().do_login()
 
-        requests = latest_requests()
         auth_request = next(
-            r for r in requests if self.backend.authorization_url() in r.url
+            r.request
+            for r in responses.calls
+            if r.request.url.startswith(self.backend.authorization_url())
+        )
+        code_challenge = get_querystring(cast("str", auth_request.url)).get(
+            "code_challenge"
+        )
+        code_challenge_method = get_querystring(cast("str", auth_request.url)).get(
+            "code_challenge_method"
         )
-        code_challenge = auth_request.querystring.get("code_challenge")[0]
-        code_challenge_method = auth_request.querystring.get("code_challenge_method")[0]
         self.assertIsNotNone(code_challenge)
         self.assertEqual(code_challenge_method, "plain")
 
         auth_complete = next(
-            r for r in requests if self.backend.access_token_url() in r.url
+            r.request
+            for r in responses.calls
+            if r.request.url.startswith(self.backend.access_token_url())
         )
-        code_verifier = auth_complete.parsed_body.get("code_verifier")[0]
+        code_verifier = parse_qs(auth_complete.body).get("code_verifier")
         self.assertEqual(code_challenge, code_verifier)
 
         return user
@@ -162,19 +179,26 @@ class OAuth2PkceS256Test(OAuth2Test):
         # use default value of PKCE_CODE_CHALLENGE_METHOD (s256)
         user = super().do_login()
 
-        requests = latest_requests()
         auth_request = next(
-            r for r in requests if self.backend.authorization_url() in r.url
+            r.request
+            for r in responses.calls
+            if r.request.url.startswith(self.backend.authorization_url())
+        )
+        code_challenge = get_querystring(cast("str", auth_request.url)).get(
+            "code_challenge"
+        )
+        code_challenge_method = get_querystring(cast("str", auth_request.url)).get(
+            "code_challenge_method"
         )
-        code_challenge = auth_request.querystring.get("code_challenge")[0]
-        code_challenge_method = auth_request.querystring.get("code_challenge_method")[0]
         self.assertIsNotNone(code_challenge)
         self.assertTrue(code_challenge_method in ["s256", "S256"])
 
         auth_complete = next(
-            r for r in requests if self.backend.access_token_url() in r.url
+            r.request
+            for r in responses.calls
+            if r.request.url.startswith(self.backend.access_token_url())
         )
-        code_verifier = auth_complete.parsed_body.get("code_verifier")[0]
+        code_verifier = parse_qs(auth_complete.body).get("code_verifier")
         self.assertEqual(
             self.backend.generate_code_challenge(code_verifier, code_challenge_method),
             code_challenge,
@@ -183,7 +207,9 @@ class OAuth2PkceS256Test(OAuth2Test):
         return user
 
 
-class BaseAuthUrlTestMixin:
+class BaseAuthUrlTestMixin(Generic[OAuthBackendT]):
+    backend: OAuthBackendT
+
     def check_parameters_in_authorization_url(self, auth_url_key="AUTHORIZATION_URL"):
         """
         Check the parameters in authorization url
@@ -215,5 +241,5 @@ class BaseAuthUrlTestMixin:
 
 class OAuth1AuthUrlTestMixin(BaseAuthUrlTestMixin):
     def test_auth_url_parameters(self):
-        self.request_token_handler()
+        self.request_token_handler()  # type: ignore[attr-defined]
         self.check_parameters_in_authorization_url()
