@@ -1,9 +1,9 @@
 import json
 
-from .oauth import OAuth2Test
+from .oauth import BaseAuthUrlTestMixin, OAuth2Test
 
 
-class AsanaOAuth2Test(OAuth2Test):
+class AsanaOAuth2Test(OAuth2Test, BaseAuthUrlTestMixin):
     backend_path = "social_core.backends.asana.AsanaOAuth2"
     user_data_url = "https://app.asana.com/api/1.0/users/me"
     expected_username = "erlich@bachmanity.com"
