@@ -26,10 +26,10 @@ SOFTWARE.
 
 import json
 
-from .oauth import OAuth2Test
+from .oauth import BaseAuthUrlTestMixin, OAuth2Test
 
 
-class AzureADOAuth2Test(OAuth2Test):
+class AzureADOAuth2Test(OAuth2Test, BaseAuthUrlTestMixin):
     backend_path = "social_core.backends.azuread.AzureADOAuth2"
     user_data_url = "https://graph.windows.net/me"
     expected_username = "foobar"
