@@ -24,15 +24,21 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
+from __future__ import annotations
+
 import json
 from time import time
+from typing import TYPE_CHECKING, cast
 
 import jwt
-from httpretty import HTTPretty
+import responses
 from jwt.algorithms import RSAAlgorithm
 
 from .oauth import BaseAuthUrlTestMixin, OAuth2Test
 
+if TYPE_CHECKING:
+    from cryptography.hazmat.primitives.asymmetric.rsa import RSAPrivateKey
+
 # Dummy private and private keys:
 RSA_PUBLIC_JWT_KEY = {
     # https://github.com/jpadilla/pyjwt/blob/06f461a/tests/keys/jwk_rsa_pub.json
@@ -107,7 +113,10 @@ class AzureADB2COAuth2Test(OAuth2Test, BaseAuthUrlTestMixin):
             "access_token": "foobar",
             "token_type": "bearer",
             "id_token": jwt.encode(
-                key=RSAAlgorithm.from_jwk(json.dumps(RSA_PRIVATE_JWT_KEY)),  # type: ignore reportOperatorIssue
+                key=cast(
+                    "RSAPrivateKey",
+                    RSAAlgorithm.from_jwk(json.dumps(RSA_PRIVATE_JWT_KEY)),
+                ),
                 headers={
                     "kid": RSA_PRIVATE_JWT_KEY["kid"],
                 },
@@ -173,7 +182,7 @@ class AzureADB2COAuth2Test(OAuth2Test, BaseAuthUrlTestMixin):
                 ],
             }
         )
-        HTTPretty.register_uri(HTTPretty.GET, keys_url, status=200, body=keys_body)
+        responses.add(responses.GET, keys_url, status=200, body=keys_body)
 
     def test_login(self):
         self.do_login()
