@@ -1,12 +1,12 @@
-import unittest2 as unittest
+import unittest
 
 from ...backends.base import BaseAuth
-from ..strategy import TestStrategy
 from ..models import TestStorage
+from ..strategy import TestStrategy
 
 
 class BrokenBackendAuth(BaseAuth):
-    name = 'broken'
+    name = "broken"
 
 
 class BrokenBackendTest(unittest.TestCase):
@@ -17,21 +17,17 @@ class BrokenBackendTest(unittest.TestCase):
         self.backend = None
 
     def test_auth_url(self):
-        with self.assertRaisesRegex(NotImplementedError,
-                                    'Implement in subclass'):
+        with self.assertRaisesRegex(NotImplementedError, "Implement in subclass"):
             self.backend.auth_url()
 
     def test_auth_html(self):
-        with self.assertRaisesRegex(NotImplementedError,
-                                    'Implement in subclass'):
+        with self.assertRaisesRegex(NotImplementedError, "Implement in subclass"):
             self.backend.auth_html()
 
     def test_auth_complete(self):
-        with self.assertRaisesRegex(NotImplementedError,
-                                    'Implement in subclass'):
+        with self.assertRaisesRegex(NotImplementedError, "Implement in subclass"):
             self.backend.auth_complete()
 
     def test_get_user_details(self):
-        with self.assertRaisesRegex(NotImplementedError,
-                                    'Implement in subclass'):
+        with self.assertRaisesRegex(NotImplementedError, "Implement in subclass"):
             self.backend.get_user_details(None)
