@@ -1,9 +1,9 @@
 import json
 
-from .oauth import OAuth2Test
+from .oauth import BaseAuthUrlTestMixin, OAuth2Test
 
 
-class DeezerOAuth2Test(OAuth2Test):
+class DeezerOAuth2Test(OAuth2Test, BaseAuthUrlTestMixin):
     backend_path = "social_core.backends.deezer.DeezerOAuth2"
     user_data_url = "http://api.deezer.com/user/me"
     expected_username = "foobar"
