@@ -1,9 +1,9 @@
 import json
 
-from .oauth import OAuth2Test
+from .oauth import BaseAuthUrlTestMixin, OAuth2Test
 
 
-class DribbbleOAuth2Test(OAuth2Test):
+class DribbbleOAuth2Test(OAuth2Test, BaseAuthUrlTestMixin):
     backend_path = "social_core.backends.dribbble.DribbbleOAuth2"
     user_data_url = "https://api.dribbble.com/v1/user"
     expected_username = "foobar"
