@@ -1,9 +1,9 @@
 import json
 
-from .oauth import OAuth2Test
+from .oauth import BaseAuthUrlTestMixin, OAuth2Test
 
 
-class DropboxOAuth2Test(OAuth2Test):
+class DropboxOAuth2Test(OAuth2Test, BaseAuthUrlTestMixin):
     backend_path = "social_core.backends.dropbox.DropboxOAuth2V2"
     user_data_url = "https://api.dropboxapi.com/2/users/get_current_account"
     user_data_url_post = True
