@@ -1,9 +1,9 @@
 import json
 
-from .oauth import OAuth2Test
+from .oauth import BaseAuthUrlTestMixin, OAuth2Test
 
 
-class EdmodoOAuth2Test(OAuth2Test):
+class EdmodoOAuth2Test(OAuth2Test, BaseAuthUrlTestMixin):
     backend_path = "social_core.backends.edmodo.EdmodoOAuth2"
     user_data_url = "https://api.edmodo.com/users/me"
     expected_username = "foobar12345"
