@@ -1,9 +1,9 @@
 import json
 
-from .oauth import OAuth2Test
+from .oauth import BaseAuthUrlTestMixin, OAuth2Test
 
 
-class LyftOAuth2Test(OAuth2Test):
+class LyftOAuth2Test(OAuth2Test, BaseAuthUrlTestMixin):
     backend_path = "social_core.backends.lyft.LyftOAuth2"
     user_data_url = "https://api.lyft.com/v1/profile"
     access_token_body = json.dumps(
