@@ -1,9 +1,9 @@
 import json
 
-from .oauth import OAuth2Test
+from .oauth import BaseAuthUrlTestMixin, OAuth2Test
 
 
-class NaverOAuth2Test(OAuth2Test):
+class NaverOAuth2Test(OAuth2Test, BaseAuthUrlTestMixin):
     backend_path = "social_core.backends.naver.NaverOAuth2"
     user_data_url = "https://openapi.naver.com/v1/nid/me"
     expected_username = "foobar"
