@@ -1,9 +1,9 @@
 import json
 
-from .oauth import OAuth2Test
+from .oauth import BaseAuthUrlTestMixin, OAuth2Test
 
 
-class QuizletOAuth2Test(OAuth2Test):
+class QuizletOAuth2Test(OAuth2Test, BaseAuthUrlTestMixin):
     backend_path = "social_core.backends.quizlet.QuizletOAuth2"
     expected_username = "foo_bar"
 
