@@ -1,9 +1,9 @@
 import json
 
-from .oauth import OAuth2Test
+from .oauth import BaseAuthUrlTestMixin, OAuth2Test
 
 
-class SketchfabOAuth2Test(OAuth2Test):
+class SketchfabOAuth2Test(OAuth2Test, BaseAuthUrlTestMixin):
     backend_path = "social_core.backends.sketchfab.SketchfabOAuth2"
     user_data_url = "https://sketchfab.com/v2/users/me"
     expected_username = "foobar"
