@@ -1,9 +1,9 @@
 import json
 
-from .oauth import OAuth2Test
+from .oauth import BaseAuthUrlTestMixin, OAuth2Test
 
 
-class StocktwitsOAuth2Test(OAuth2Test):
+class StocktwitsOAuth2Test(OAuth2Test, BaseAuthUrlTestMixin):
     backend_path = "social_core.backends.stocktwits.StocktwitsOAuth2"
     user_data_url = "https://api.stocktwits.com/api/2/account/verify.json"
     expected_username = "foobar"
