@@ -1,10 +1,10 @@
 import json
 from urllib.parse import urlencode
 
-from .oauth import OAuth1Test
+from .oauth import OAuth1AuthUrlTestMixin, OAuth1Test
 
 
-class TripitOAuth1Test(OAuth1Test):
+class TripitOAuth1Test(OAuth1Test, OAuth1AuthUrlTestMixin):
     backend_path = "social_core.backends.tripit.TripItOAuth"
     user_data_url = "https://api.tripit.com/v1/get/profile"
     expected_username = "foobar"
