@@ -1,10 +1,10 @@
 import json
 from urllib.parse import urlencode
 
-from .oauth import OAuth1Test
+from .oauth import OAuth1AuthUrlTestMixin, OAuth1Test
 
 
-class TumblrOAuth1Test(OAuth1Test):
+class TumblrOAuth1Test(OAuth1Test, OAuth1AuthUrlTestMixin):
     backend_path = "social_core.backends.tumblr.TumblrOAuth"
     user_data_url = "http://api.tumblr.com/v2/user/info"
     expected_username = "foobar"
