@@ -1,9 +1,9 @@
 import json
 
-from .oauth import OAuth2Test
+from .oauth import BaseAuthUrlTestMixin, OAuth2Test
 
 
-class WunderlistOAuth2Test(OAuth2Test):
+class WunderlistOAuth2Test(OAuth2Test, BaseAuthUrlTestMixin):
     backend_path = "social_core.backends.wunderlist.WunderlistOAuth2"
     user_data_url = "https://a.wunderlist.com/api/v1/user"
     expected_username = "12345"
