@@ -5,16 +5,14 @@ from ..pipeline.partial import partial
 def ask_for_password(strategy, *args, **kwargs):
     if strategy.session_get("password"):
         return {"password": strategy.session_get("password")}
-    else:
-        return strategy.redirect(strategy.build_absolute_uri("/password"))
+    return strategy.redirect(strategy.build_absolute_uri("/password"))
 
 
 @partial
 def ask_for_slug(strategy, *args, **kwargs):
     if strategy.session_get("slug"):
         return {"slug": strategy.session_get("slug")}
-    else:
-        return strategy.redirect(strategy.build_absolute_uri("/slug"))
+    return strategy.redirect(strategy.build_absolute_uri("/slug"))
 
 
 def set_password(strategy, user, *args, **kwargs):
@@ -33,13 +31,13 @@ def remove_user(strategy, user, *args, **kwargs):
 def set_user_from_kwargs(strategy, *args, **kwargs):
     if strategy.session_get("attribute"):
         kwargs["user"].id
-    else:
-        return strategy.redirect(strategy.build_absolute_uri("/attribute"))
+        return None
+    return strategy.redirect(strategy.build_absolute_uri("/attribute"))
 
 
 @partial
 def set_user_from_args(strategy, user, *args, **kwargs):
     if strategy.session_get("attribute"):
         user.id
-    else:
-        return strategy.redirect(strategy.build_absolute_uri("/attribute"))
+        return None
+    return strategy.redirect(strategy.build_absolute_uri("/attribute"))
